==> knative-model-5.4.1-sources.jar: io/fabric8/knative/eventing/v1/TriggerSpecFluent.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Deprecated;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface TriggerSpecFluent<A extends io.fabric8.knative.eventing.v1.TriggerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.String getBroker();
    public A withBroker(java.lang.String broker);
    public java.lang.Boolean hasBroker();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withBroker instead.
     */
        public A withNewBroker(java.lang.String arg0);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildFilter instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.eventing.v1.TriggerFilter getFilter();
    public io.fabric8.knative.eventing.v1.TriggerFilter buildFilter();
    public A withFilter(io.fabric8.knative.eventing.v1.TriggerFilter filter);
    public java.lang.Boolean hasFilter();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> withNewFilter();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> withNewFilterLike(io.fabric8.knative.eventing.v1.TriggerFilter item);
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editFilter();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editOrNewFilter();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editOrNewFilterLike(io.fabric8.knative.eventing.v1.TriggerFilter item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildSubscriber instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.internal.pkg.apis.duck.v1.Destination getSubscriber();
    public io.fabric8.knative.internal.pkg.apis.duck.v1.Destination buildSubscriber();
    public A withSubscriber(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination subscriber);
    public java.lang.Boolean hasSubscriber();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> withNewSubscriber();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> withNewSubscriberLike(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item);
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editSubscriber();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriber();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriberLike(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item);
    public interface FilterNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.v1.TriggerFilterFluent<io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<N>> {

            public N and();
            public N endFilter();    }


    public interface SubscriberNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent<io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<N>> {

            public N and();
            public N endSubscriber();    }


}

==> knative-model-5.7.1-sources.jar: io/fabric8/knative/eventing/v1/TriggerSpecFluent.java <==
package io.fabric8.knative.eventing.v1;

import io.fabric8.knative.internal.pkg.apis.duck.v1.Destination;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluent;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecBuilder;
import io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationBuilder;
import java.lang.Object;
import java.util.Map;

public interface TriggerSpecFluent<A extends io.fabric8.knative.eventing.v1.TriggerSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public java.lang.String getBroker();
    public A withBroker(java.lang.String broker);
    public java.lang.Boolean hasBroker();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withBroker instead.
     */
        public A withNewBroker(java.lang.String arg0);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildDelivery instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec getDelivery();
    public io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec buildDelivery();
    public A withDelivery(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec delivery);
    public java.lang.Boolean hasDelivery();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> withNewDelivery();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> withNewDeliveryLike(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec item);
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> editDelivery();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> editOrNewDelivery();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<A> editOrNewDeliveryLike(io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpec item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildFilter instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.eventing.v1.TriggerFilter getFilter();
    public io.fabric8.knative.eventing.v1.TriggerFilter buildFilter();
    public A withFilter(io.fabric8.knative.eventing.v1.TriggerFilter filter);
    public java.lang.Boolean hasFilter();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> withNewFilter();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> withNewFilterLike(io.fabric8.knative.eventing.v1.TriggerFilter item);
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editFilter();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editOrNewFilter();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<A> editOrNewFilterLike(io.fabric8.knative.eventing.v1.TriggerFilter item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildSubscriber instead.
     * @return The buildable object.
     */
        public io.fabric8.knative.internal.pkg.apis.duck.v1.Destination getSubscriber();
    public io.fabric8.knative.internal.pkg.apis.duck.v1.Destination buildSubscriber();
    public A withSubscriber(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination subscriber);
    public java.lang.Boolean hasSubscriber();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> withNewSubscriber();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> withNewSubscriberLike(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item);
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editSubscriber();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriber();
    public io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<A> editOrNewSubscriberLike(io.fabric8.knative.internal.pkg.apis.duck.v1.Destination item);
    public interface DeliveryNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.internal.eventing.pkg.apis.duck.v1.DeliverySpecFluent<io.fabric8.knative.eventing.v1.TriggerSpecFluent.DeliveryNested<N>> {

            public N and();
            public N endDelivery();    }


    public interface FilterNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.eventing.v1.TriggerFilterFluent<io.fabric8.knative.eventing.v1.TriggerSpecFluent.FilterNested<N>> {

            public N and();
            public N endFilter();    }


    public interface SubscriberNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.internal.pkg.apis.duck.v1.DestinationFluent<io.fabric8.knative.eventing.v1.TriggerSpecFluent.SubscriberNested<N>> {

            public N and();
            public N endSubscriber();    }


}
